/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.htmlcheck.filters;

import java.util.*;
import org.w3c.dom.*;
import com.silverwrist.util.*;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.htmlcheck.Rewriter;
import com.silverwrist.venice.htmlcheck.RewriterServices;
import com.silverwrist.venice.htmlcheck.MarkupData;
import com.silverwrist.venice.util.XMLLoader;

public class EmoticonRewriter implements Rewriter
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_prefixchars;
  private Map m_patmap;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public EmoticonRewriter(String config_file) throws ConfigException
  {
    // Load the configuration file.
    XMLLoader loader = XMLLoader.get();
    Document config = loader.loadConfigDocument(config_file);
    Element root = loader.configGetRootElement(config,"emoticon-config");

    // Get the set of prefix characters.
    m_prefixchars = loader.configGetSubElementText(root,"prefix-chars");

    HashMap tmp = new HashMap();

    // Look for all associated icons.
    NodeList nl = root.getChildNodes();
    for (int i=0; i<nl.getLength(); i++)
    { // look through all the child nodes...
      Node n = nl.item(i);
      if ((n.getNodeType()==Node.ELEMENT_NODE) && n.getNodeName().equals("icon"))
      { // load the icon name
	String icon_name = loader.configGetAttribute((Element)n,"name").intern();

	// get the associated patterns
	NodeList nl2 = n.getChildNodes();
	for (int j=0; j<nl2.getLength(); j++)
	{ // look for <pattern/> elements
	  Node n2 = nl2.item(i);
	  if ((n2.getNodeType()==Node.ELEMENT_NODE) && n2.getNodeName().equals("pattern"))
	  { // get the element text
	    DOMElementHelper h = new DOMElementHelper((Element)n2);
	    String pattern = h.getElementText();
	    if (m_prefixchars.indexOf(pattern.charAt(0))>=0)
	      tmp.put(pattern,icon_name);

	  } // end if
	  // else skip this element

	} // end for
	
      } // end if
      // else skip this element

    } // end for

    if (tmp.isEmpty())
      m_patmap = Collections.EMPTY_MAP;
    else
      m_patmap = Collections.unmodifiableMap(tmp);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface Rewriter
   *--------------------------------------------------------------------------------
   */

  public String getName()
  {
    return "emoticon";

  } // end getName

  public MarkupData rewrite(String data, RewriterServices svc)
  {
    return null;

  } // end rewrite

} // end class EmoticonRewriter
